@@ -93,11 +93,10 @@ class CustomTitlebarWindow(FramelessWindow):
 
     def eventFilter(self, obj, e) -> bool:
         if obj == self:
-            # catch resize event or window state change event
-            if e.type() == 14 or e.type() == 105:
-                # prevent the problem that top title bar window is not visible when full screen turning off
-                if e.type() == 105:
-                    if int(e.oldState()) == 4:
+            # prevent the problem that top title bar window is not visible when full screen turning off
+            if e.type() == 105:
+                if int(e.oldState()) == 4:
+                    if isinstance(self.__topTitleBar, TopTitleBarWidget):
                         self.__topTitleBar.show()
         # catch full screen toggle event
         if obj.objectName() == 'mainWidget':
